@@ -11,6 +11,9 @@ async def _extract_form_data(request: Request):
     return await request.form()
 
 
+WholeForm = lambda: Depends(_extract_form_data)
+
+
 def _copy_dependencies(source_function: Callable, dest_function: Callable):
     source_signature = inspect.signature(source_function)
     dest_signature = inspect.signature(dest_function)
@@ -51,7 +54,7 @@ class FormController(Controller):
                 return self.render(cls.template, context={"form": cls.form()})
 
             @router.post(cls.url)
-            def handle_form_page(self, form_data=Depends(_extract_form_data), **kw):
+            def handle_form_page(self, form_data=WholeForm(), **kw):
                 form = cls.form(formdata=form_data)
                 if not form.validate():
                     return self.render(cls.template, context={"form": form}, status_code=400)
